@@ -44,7 +44,7 @@ Adjusted_log_CI_2x2 <- function(n, alpha = 0.05) {
   }
   return(
     contingencytables_result(
-      list(lower = L, upper = U, estimate = estimate), printresults
+      list("lower" = L, "upper" = U, "estimate" = estimate), printresults
     )
   )
 }
