@@ -28,7 +28,11 @@ AgrestiCaffo_CI_2x2 <- function(n, alpha = 0.05) {
 
   return(
     contingencytables_result(
-      list(lower = res.wald$lower, upper = res.wald$upper, estimate = estimate),
+      list(
+        "lower" = res.wald$lower,
+        "upper" = res.wald$upper,
+        "estimate" = estimate
+      ),
       printresults
     )
   )
