@@ -55,7 +55,7 @@ Cornfield_midP_CI_2x2 <- function(n, alpha = 0.05) {
   }
   return(
     contingencytables_result(
-      list(lower = L, upper = U, estimate = estimate),
+      list("lower" = L, "upper" = U, "estimate" = estimate),
       printresults
     )
   )
