@@ -49,7 +49,7 @@ Fisher_midP_test_2x2 <- function(n, statistic = "hypergeometric") {
     "LR" = "The Fisher mid-P test (LR): P = %7.5f"
   )
 
-  return(contingencytables_result(list("P" = P), sprintf(txt, P)))
+  return(contingencytables_result(list("Pvalue" = P), sprintf(txt, P)))
 }
 
 # ========================================================
