@@ -44,7 +44,7 @@ FleissLevinPaik_test_paired_cxc <- function(n) {
 
   return(
     contingencytables_result(
-      list(P = P, T = T0, df = df),
+      list("Pvalue" = P, "T" = T0, "df" = df),
       sprintf("The Fleiss-Levin-Paik test: P = %8.6f, T = %6.3f (df=%g)",
         P, T0, df
       )
