@@ -33,7 +33,7 @@ LR_test_1xc <- function(n, pi0) {
 
   return(
     contingencytables_result(
-      list("P" = P, "T" = T0, "df" = df),
+      list("Pvalue" = P, "T" = T0, "df" = df),
       sprintf("The likelihood ratio test: P = %7.5f, T = %5.3f (df = %i)", P, T0, df)
     )
   )
