@@ -39,7 +39,7 @@ MantelHaenszel_test_2xc <- function(n, b = 0) {
 
   return(
     contingencytables_result(
-      list(P = P, T = T0, df = df),
+      list("Pvalue" = P, "T" = T0, "df" = df),
       sprintf(
         "Mantel-Haenszel test of association: P = %6.4f, T = %5.3f (df=%g)",
         P, T0, df
