@@ -5,21 +5,24 @@
 #' @param X the number of successes
 #' @param n the total number of observations
 #' @param pi0 a given probability
-#' @param printresults display results (0 = no, 1 = yes)
 #' @examples
 #' # The number of 1st order male births (Singh et al. 2010, adapted)
-#' MidP_binomial_test_1x2(X = 250, n = 533, pi0 = .5)
+#' MidP_binomial_test_1x2(singh_2010["1st", "X"], singh_2010["1st", "n"], pi0 = .5)
 #' # The number of 2nd order male births (Singh et al. 2010, adapted)
-#' MidP_binomial_test_1x2(X = 204, n = 412, pi0 = .5)
+#' MidP_binomial_test_1x2(singh_2010["2nd", "X"], singh_2010["2nd", "n"], pi0 = .5)
 #' # The number of 3rd order male births (Singh et al. 2010, adapted)
-#' MidP_binomial_test_1x2(X = 103, n = 167, pi0 = .5)
+#' MidP_binomial_test_1x2(singh_2010["3rd", "X"], singh_2010["3rd", "n"], pi0 = .5)
 #' # The number of 4th order male births (Singh et al. 2010, adapted)
-#' MidP_binomial_test_1x2(X = 33, n = 45, pi0 = .5)
+#' MidP_binomial_test_1x2(singh_2010["4th", "X"], singh_2010["4th", "n"], pi0 = .5)
 #' # Ligarden et al. (2010, adapted)
-#' MidP_binomial_test_1x2(X = 13, n = 16, pi0 = .5)
+#' MidP_binomial_test_1x2(ligarden_2010["X"], ligarden_2010["n"], pi0 = .5)
 #' @export
-#' @return probability value
-MidP_binomial_test_1x2 <- function(X, n, pi0, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+MidP_binomial_test_1x2 <- function(X, n, pi0) {
+  validateArguments(mget(ls()))
+
   # The right tail mid-P value (for H_A: pi > pi0)
   midPright <- sum(dbinom(X:n, n, pi0))
   midPright <- midPright - 0.5 * dbinom(X, n, pi0)
@@ -32,9 +35,9 @@ MidP_binomial_test_1x2 <- function(X, n, pi0, printresults = TRUE) {
   midP <- 2 * min(midPright, midPleft)
   midP <- min(midP, 1)
 
-  if (printresults) {
-    print(sprintf("The mid-P binomial test: P = %7.5f", midP), quote = FALSE)
-  }
-
-  invisible(midP)
+  return(
+    contingencytables_result(
+      list("midP" = midP), sprintf("The mid-P binomial test: P = %7.5f", midP)
+    )
+  )
 }
