@@ -55,7 +55,7 @@ gamma_coefficient_rxc_bca <- function(n, nboot = 10000, alpha = 0.05) {
 
   return(
     contingencytables_result(
-      list(gamma = gamma, L = L, U = U),
+      list("gamma" = gamma, "lower" = L, "upper" = U),
       sprintf("The gamma coefficient w / BCa bootstrap CI: gamma = %7.4f (%g%% CI %7.4f to %7.4f)",
         gamma, 100 * (1 - alpha), L, U
       )
