@@ -28,50 +28,50 @@ the_2x2_table_tests <- function(n, gamma = 0.0001) {
   cat("Test                                  P-value  (test statistic)\n")
   cat("------------------------------------------------------------------\n")
   res <- Pearson_chi_squared_test_2x2(n)
-  P0 <- res$p.value
-  T0 <- res$statistic
+  P0 <- res$Pvalue
+  T0 <- res$T
   df <- res$df
   cat_sprintf("Pearson chi-squared                     %6.4f (T = %5.3f, df = %i)\n", P0, T0, df)
 
   res <- Pearson_chi_squared_test_CC_2x2(n)
-  P0 <- res$p.value
-  T0 <- res$statistic
+  P0 <- res$Pvalue
+  T0 <- res$T
   df <- res$df
   cat_sprintf("Pearson chi-squared w / CC              %6.4f (T = %5.3f, df = %i)\n", P0, T0, df)
 
   res <- LR_test_2x2(n)
-  P0 <- res$p.value
-  T0 <- res$statistic
+  P0 <- res$Pvalue
+  T0 <- res$T
   df <- res$df
   cat_sprintf("Likelihood ratio                        %6.4f (T = %5.3f, df = %i)\n", P0, T0, df)
 
   res <- Z_unpooled_test_2x2(n)
-  P0 <- res$p.value
-  Z0 <- res$statistic
+  P0 <- res$Pvalue
+  Z0 <- res$T
   cat_sprintf("Z-unpooled                              %6.4f (Z = %5.3f)\n", P0, Z0)
 
-  P0 <- Fisher_exact_test_2x2(n, "hypergeometric")$P
+  P0 <- Fisher_exact_test_2x2(n, "hypergeometric")$Pvalue
   cat_sprintf("Fisher exact test (Fisher-Irwin)        %6.4f\n", P0)
 
-  P0 <- Fisher_exact_test_2x2(n, "Pearson")$P
+  P0 <- Fisher_exact_test_2x2(n, "Pearson")$Pvalue
   cat_sprintf("Fisher exact test (Pearson)             %6.4f\n", P0)
 
-  P0 <- Fisher_exact_test_2x2(n, "LR")$P
+  P0 <- Fisher_exact_test_2x2(n, "LR")$Pvalue
   cat_sprintf("Fisher exact test (LR)                  %6.4f\n", P0)
 
-  P0 <- Fisher_midP_test_2x2(n, "hypergeometric")$P
+  P0 <- Fisher_midP_test_2x2(n, "hypergeometric")$Pvalue
   cat_sprintf("Fisher mid-P test (Fisher-Irwin)        %6.4f\n", P0)
 
-  P0 <- Exact_unconditional_test_2x2(n, "Pearson", gamma)$P
+  P0 <- Exact_unconditional_test_2x2(n, "Pearson", gamma)$Pvalue
   cat_sprintf("Suissa-Shuster exact uncond.*           %6.4f\n", P0)
 
-  P0 <- Exact_unconditional_test_2x2(n, "LR", gamma)$P
+  P0 <- Exact_unconditional_test_2x2(n, "LR", gamma)$Pvalue
   cat_sprintf("Exact uncond. w / LR statistic*         %6.4f\n", P0)
 
-  P0 <- Exact_unconditional_test_2x2(n, "unpooled", gamma)$P
+  P0 <- Exact_unconditional_test_2x2(n, "unpooled", gamma)$Pvalue
   cat_sprintf("Exact uncond. w / unpooled Z statistic* %6.4f\n", P0)
 
-  P0 <- Exact_unconditional_test_2x2(n, "Fisher", gamma)$P
+  P0 <- Exact_unconditional_test_2x2(n, "Fisher", gamma)$Pvalue
   cat_sprintf("Fisher-Boschloo exact uncond.*          %6.4f\n", P0)
 
   cat("------------------------------------------------------------------\n")
