@@ -27,11 +27,11 @@ the_2xc_table <- function(n, alpha = 0.05, direction = "increasing") {
   cat_sprintf("  Pearson chi-squared           %6.3f (chibar) %8.5f\n", results$T_Pearson, results$P_Pearson)
   cat_sprintf("  Likelihood ratio              %6.3f (chibar) %8.5f\n", results$T_LR, results$P_LR)
 
-  res1 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "Pearson") # TODO: optimize, takes forever! (ISSUE #44)
-  res2 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "LR") # TODO: optimize, takes forever! (ISSUE #44)
-  cat_sprintf("  Exact conditional (Pearson)                   %8.5f\n", res1$P)
+  res1 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "Pearson")
+  res2 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "LR")
+  cat_sprintf("  Exact conditional (Pearson)                   %8.5f\n", res1$Pvalue)
   cat_sprintf("  Mid-P (Pearson)                               %8.5f\n", res1$midP)
-  cat_sprintf("  Exact conditional (LR)                        %8.5f\n", res2$P)
+  cat_sprintf("  Exact conditional (LR)                        %8.5f\n", res2$Pvalue)
   cat_sprintf("  Mid-P (LR)                                    %8.5f\n", res2$midP)
 
   cat_sprintf("\nTests for ordered cumulative odds ratios\n")
@@ -39,16 +39,16 @@ the_2xc_table <- function(n, alpha = 0.05, direction = "increasing") {
   cat_sprintf("  Pearson chi-squared           %6.3f (chibar) %8.5f\n", results$T_Pearson, results$P_Pearson)
   cat_sprintf("  Likelihood ratio              %6.3f (chibar) %8.5f\n", results$T_LR, results$P_LR)
 
-  res1 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "PearsonCumOR") # TODO: optimize, takes forever! (ISSUE #44)
-  res2 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "LRCumOR") # TODO: optimize, takes forever! (ISSUE #44)
-  cat_sprintf("  Exact conditional (Pearson)                   %8.5f\n", res1$P)
+  res1 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "PearsonCumOR")
+  res2 <- Exact_cond_midP_unspecific_ordering_rx2(t(n), direction, "LRCumOR")
+  cat_sprintf("  Exact conditional (Pearson)                   %8.5f\n", res1$Pvalue)
   cat_sprintf("  Mid-P (Pearson)                               %8.5f\n", res1$midP)
-  cat_sprintf("  Exact conditional (LR)                        %8.5f\n", res2$P)
+  cat_sprintf("  Exact conditional (LR)                        %8.5f\n", res2$Pvalue)
   cat_sprintf("  Mid-P (LR)                                    %8.5f\n", res2$midP)
 
   cat_sprintf("\nTest for association with column scores \n")
   res <- MantelHaenszel_test_2xc(n, 0)
-  cat_sprintf("  Mantel-Haenszel               %6.3f (df=%g)   %8.5f\n", res$T, res$df, res$P)
+  cat_sprintf("  Mantel-Haenszel               %6.3f (df=%g)   %8.5f\n", res$T, res$df, res$Pvalue)
 
 
   cat_sprintf("\nTesting the fit of a proportional odds model\n")
@@ -66,7 +66,7 @@ the_2xc_table <- function(n, alpha = 0.05, direction = "increasing") {
   cat_sprintf("  Score (WMW)                   %6.3f          %8.5f\n", results$Z_MW, results$P_MW)
 
   res <- Exact_cond_midP_linear_rank_tests_2xc(n, 0)
-  cat_sprintf("  Exact conditional linear rank                 %8.5f\n", res$P)
+  cat_sprintf("  Exact conditional linear rank                 %8.5f\n", res$Pvalue)
   cat_sprintf("  Mid-P linear rank                             %8.5f\n", res$midP)
 
 
@@ -80,17 +80,6 @@ the_2xc_table <- function(n, alpha = 0.05, direction = "increasing") {
   cat_sprintf("  Wald                          %6.3f          %8.5f\n", resultsProbit$Z_Wald, resultsProbit$P_Wald)
   cat_sprintf("  Likelihood ratio              %6.3f (df=%g)   %8.5f\n", resultsProbit$T_LR, resultsProbit$df_LR, resultsProbit$P_LR)
 
-  alphahat0 <- NULL
-  if (all(n == fontanella_2008)) {
-    alphahat0 <- c(-1.246452, -0.5097363, 0.2087471)
-  }
-  if (all(n == lydersen_2012a)) {
-    alphahat0 <- c(-0.1923633, 0.5588396, 1.271953)
-  }
-  if (!is.null(alphahat0)) {
-    res <- Score_test_for_effect_in_the_probit_model_2xc(n, alphahat0)
-    cat_sprintf("  Score                         %6.3f (df=%g)   %8.5f\n", res$T, res$df, res$P)
-  }
   cat_sprintf("--------------------------------------------------------\n")
   cat_sprintf("\nEstimation of the effect parameter beta with %g%% CIs\n", 100 * (1 - alpha))
   cat_sprintf("----------------------------------------------------\n")
